@@ -4,13 +4,10 @@
 Standard Manupilation modules that are not directly UI based.
 """
 from PIL import Image
-from PIL import ImageDraw
-from PIL import ImageEnhance
-from PyQt4 import QtCore as QtCore
-from PyQt4 import QtGui as QtGui 
-from filters.toolbox import pil2qpixmap
+
 from filters.display import *
 
+
 def Convert_BW(self, imageToEdit, cSource, UpdateRealImage):
 
     if DisplayWait_Enable(self,  UpdateRealImage):
